pub struct IprsCode<Zt: ZipTypes, Config: PnttConfig, const REP: usize, const CHECK: bool> { /* private fields */ }Expand description
Pseudo Reed-Solomon encoder over the integers. Internally uses a
radix-8 NTT-style recursion with a base Vandermonde matrix sized
base_len x base_dim (defaults to 64x32).
Implementations
Sourceimpl<Zt, Config, const REP: usize, const CHECK: bool> IprsCode<Zt, Config, REP, CHECK>where
Zt: ZipTypes,
Config: PnttConfig,
impl<Zt, Config, const REP: usize, const CHECK: bool> IprsCode<Zt, Config, REP, CHECK>where
Zt: ZipTypes,
Config: PnttConfig,
pub fn new(row_len: usize, depth: usize) -> Result<Self, ZipError>
Sourcepub fn new_with_optimal_depth(row_len: usize) -> Result<Self, ZipError>
pub fn new_with_optimal_depth(row_len: usize) -> Result<Self, ZipError>
Create a new IPRS code with the optimal depth heuristics trying to keep number of columns in the base matrix small. Currently, keeps number of columns <= 2^8 but this might be tweaked in the future.