Radix8PnttParams

Struct Radix8PnttParams 

pub struct Radix8PnttParams<C: Config> {
    pub row_len: usize,
    pub codeword_len: usize,
    pub depth: usize,
    pub base_len: usize,
    pub base_dim: usize,
    pub base_dim_log2: u32,
    pub base_dim_mask: usize,
    pub base_matrix: Vec<Vec<PnttInt>>,
    pub butterfly_twiddles: Vec<Vec<[[PnttInt; 8]; 7]>>,
    /* private fields */
}

Fields

row_len: usize

The length of the pseudo NTT’s input.

codeword_len: usize

The length of the pseudo NTT’s output.

depth: usize

The number of steps where NTT is performed recursively.

base_len: usize

The number of columns of the base matrix.

base_dim: usize

The number of rows of the base matrix, always a power of 2.

base_dim_log2: u32

log2 of the number of rows of the base matrix.

base_dim_mask: usize

The mask to compute i % base_dim.

base_matrix: Vec<Vec<PnttInt>>

The base matrix of the pseudo NTT.

butterfly_twiddles: Vec<Vec<[[PnttInt; 8]; 7]>>

Precomputed twiddles for every stage that already contain the relevant root-of-unity factor. This lets the butterfly apply a single multiplication per term instead of two.

Implementations

Source

impl<C: Config> Radix8PnttParams<C>

pub fn new( row_len: usize, depth: usize, rep_factor: usize, ) -> Result<Self, ZipError>

Precompute pseudo NTT parameters.