pub struct Radix8PnttParams<C: Config> {
pub row_len: usize,
pub codeword_len: usize,
pub depth: usize,
pub base_len: usize,
pub base_dim: usize,
pub base_dim_log2: u32,
pub base_dim_mask: usize,
pub base_matrix: Vec<Vec<PnttInt>>,
pub butterfly_twiddles: Vec<Vec<[[PnttInt; 8]; 7]>>,
/* private fields */
}Fields
row_len: usizeThe length of the pseudo NTT’s input.
codeword_len: usizeThe length of the pseudo NTT’s output.
depth: usizeThe number of steps where NTT is performed recursively.
base_len: usizeThe number of columns of the base matrix.
base_dim: usizeThe number of rows of the base matrix, always a power of 2.
base_dim_log2: u32log2 of the number of rows of the base matrix.
base_dim_mask: usizeThe mask to compute i % base_dim.
base_matrix: Vec<Vec<PnttInt>>The base matrix of the pseudo NTT.
butterfly_twiddles: Vec<Vec<[[PnttInt; 8]; 7]>>Precomputed twiddles for every stage that already contain the relevant root-of-unity factor. This lets the butterfly apply a single multiplication per term instead of two.
Implementations